@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2012 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: _develop.sql 4702 2012-02-19 14:59:56Z fishbone $
+-- * @version    SVN: $Id: _develop.sql 4722 2012-02-26 11:16:42Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- [開発ウィジェット登録]   *****仕様変更あり注意*****
@@ -19,17 +19,6 @@
 
 -- フォトギャラリー設定マスター
 
-
-
--- 運用ログトラン
-ALTER TABLE _operation_log ADD ol_widget_id         VARCHAR(50)    DEFAULT ''                    NOT NULL;      -- ウィジェットID(ファイル名)
-
--- ページ定義マスター
-ALTER TABLE _page_def ADD pd_password          CHAR(32)       DEFAULT ''                    NOT NULL;      -- アクセス制限パスワード(MD5)
-
--- 汎用コンテンツマスター
-ALTER TABLE content ADD cn_password          CHAR(32)       DEFAULT ''                    NOT NULL;      -- アクセス制限パスワード(MD5)
-
 -- ウィジェット情報
 DELETE FROM _widgets WHERE wd_id = 'photo_cart';
 INSERT INTO _widgets 
